summaryrefslogtreecommitdiffstats
path: root/kbruch/src/exerciseconvert.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kbruch/src/exerciseconvert.cpp')
-rw-r--r--kbruch/src/exerciseconvert.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/kbruch/src/exerciseconvert.cpp b/kbruch/src/exerciseconvert.cpp
index 967c960d..6112db90 100644
--- a/kbruch/src/exerciseconvert.cpp
+++ b/kbruch/src/exerciseconvert.cpp
@@ -24,7 +24,7 @@
#include <kmessagebox.h>
#include <knumvalidator.h>
/* these includes are needed for Qt support */
#include <tqlabel.h>
#include <tqlayout.h>
#include <tqlineedit.h>
@@ -41,8 +41,8 @@
/* ----- public member functions ----- */
/* constructor */
-ExerciseConvert::ExerciseConvert(TQWidget * parent, const char * name):
- ExerciseBase(parent, name)
+ExerciseConvert::ExerciseConvert(TQWidget * tqparent, const char * name):
+ ExerciseBase(tqparent, name)
{
#ifdef DEBUG
kdDebug() << "constructor ExerciseConvert()" << endl;
@@ -119,10 +119,10 @@ ExerciseConvert::ExerciseConvert(TQWidget * parent, const char * name):
// --- that is the end of the horizontal line ---
// in RTL desktops, we still need to allign the
- // execise to the left. On Qt4, you can set the direction
- // of the layout to LTR (instead of inherit), but on Qt3
+ // execise to the left. On TQt4, you can set the direction
+ // of the tqlayout to LTR (instead of inherit), but on TQt3
// the only way of fixing it is inserting the widgets in reversed
- // order to the layout.
+ // order to the tqlayout.
//
// if you need help with this feel free to contact me - Diego <elcuco@kde.org> )
// This should fix parts of bug #116831
@@ -157,13 +157,13 @@ ExerciseConvert::ExerciseConvert(TQWidget * parent, const char * name):
m_checkButton->setText(i18n("&Check Task"));
m_checkButton->setDefault(true); // is the default button of the dialog
TQToolTip::add(m_checkButton, i18n("Click on this button to check your result. The button will not work if you have not entered a result yet."));
- lowerHBox->addWidget(m_checkButton, 1, Qt::AlignRight);
+ lowerHBox->addWidget(m_checkButton, 1, TQt::AlignRight);
TQObject::connect(m_checkButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotCheckButtonClicked()));
// that the user can start typing without moving the focus
numer_edit->setFocus();
- // show the whole layout
+ // show the whole tqlayout
baseWidget->show();
// add tooltip and qwhatsthis help to the widget
@@ -178,7 +178,7 @@ ExerciseConvert::~ExerciseConvert()
kdDebug() << "destructor ExerciseConvert()" << endl;
#endif
/* no need to delete any child widgets, Qt does it by itself */
}
/** resets the current state, creates a new task and count the last task as
@@ -24,7 +24,7 @@
#include <kmessagebox.h>
#include <knumvalidator.h>
-/* these includes are needed for Qt support */
+/* these includes are needed for TQt support */
#include <tqlabel.h>
#include <tqlayout.h>
@@ -178,7 +178,7 @@ ExerciseConvert::~ExerciseConvert()
kdDebug() << "destructor ExerciseConvert()" << endl;
#endif
- /* no need to delete any child widgets, Qt does it by itself */
+ /* no need to delete any child widgets, TQt does it by itself */
}
/** resets the current state, creates a new task and count the last task as